=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2008-04-24 07:22:53 +0000
+++ bzrlib/progress.py	2008-12-15 06:31:20 +0000
@@ -292,6 +292,7 @@
         self._max_last_updates = 10
         self.child_fraction = 0
         self._have_output = False
+        self._last_transport_msg = ''
     
     def throttle(self, old_msg):
         """Return True if the bar was updated too recently"""
@@ -329,8 +330,12 @@
         self.tick()
 
     def update(self, msg, current_cnt=None, total_cnt=None,
-               child_fraction=0):
-        """Update and redraw progress bar."""
+               child_fraction=0, transport_msg=None):
+        """Update and redraw progress bar.
+        
+        :param transport_msg: A short message inserted into the string to 
+            show the state of network activity.
+            """
         if msg is None:
             msg = self.last_msg
 
@@ -356,6 +361,11 @@
         ##     self.child_fraction == child_fraction):
         ##     return
 
+        if transport_msg is None:
+            transport_msg = self._last_transport_msg
+        if msg is None:
+            msg = ''
+
         old_msg = self.last_msg
         # save these for the tick() function
         self.last_msg = msg
@@ -401,12 +411,12 @@
             # make both fields the same size
             t = '%i' % (self.last_total)
             c = '%*i' % (len(t), self.last_cnt)
-            count_str = ' ' + c + '/' + t 
+            count_str = ' ' + c + '/' + t
 
         if self.show_bar:
             # progress bar, if present, soaks up all remaining space
             cols = self.width - 1 - len(self.last_msg) - len(spin_str) - len(pct_str) \
-                   - len(eta_str) - len(count_str) - 3
+                   - len(eta_str) - len(count_str) - 3 - len(transport_msg)
 
             if self.last_total:
                 # number of markers highlighted in bar
@@ -425,7 +435,8 @@
         else:
             bar_str = ''
 
-        m = spin_str + bar_str + self.last_msg + count_str + pct_str + eta_str
+        m = spin_str + transport_msg + bar_str + self.last_msg + count_str \
+            + pct_str + eta_str
         self.to_file.write('\r%-*.*s' % (self.width - 1, self.width - 1, m))
         self._have_output = True
         #self.to_file.flush()

=== modified file 'bzrlib/ui/text.py'
--- bzrlib/ui/text.py	2008-12-15 01:01:23 +0000
+++ bzrlib/ui/text.py	2008-12-15 06:31:20 +0000
@@ -49,8 +49,7 @@
                          select.
         """
         super(TextUIFactory, self).__init__()
-        # XXX: mbp, temporarily disabled so we can see the network progress
-        self._bar_type = progress.DummyProgress # bar_type
+        self._bar_type = bar_type
         if stdout is None:
             self.stdout = sys.stdout
         else:
@@ -63,6 +62,9 @@
         self._total_byte_count = 0
         self._bytes_since_update = 0
         self._last_activity_time = None
+        # there must always be a top-level progress bar, even if it's not
+        # always shown.
+        self.nested_progress_bar()
 
     def prompt(self, prompt):
         """Emit prompt on the CLI."""
@@ -84,6 +86,10 @@
 
         This will, clear any progress bars, and leave the cursor at the
         leftmost position."""
+        # XXX: If this is preparing to write to stdout, but that's for example
+        # directed into a file rather than to the terminal, and the progress
+        # bar _is_ going to the terminal, we shouldn't need
+        # to clear it.  We might need to separately check for the case of 
         if self._progress_bar_stack is None:
             return
         overall_pb = self._progress_bar_stack.bottom()
@@ -107,7 +113,9 @@
             # guard against clock stepping backwards, and don't update too
             # often
             rate = self._bytes_since_update / (now - self._last_activity_time)
-            sys.stderr.write("transport %6dkB @ %6.1fkB/s                            \r" %
+            msg = ("%6dkB @ %6.1fkB/s" %
                 (self._total_byte_count>>10, int(rate)>>10,))
             self._last_activity_time = now
             self._bytes_since_update = 0
+            overall_pb = self._progress_bar_stack.bottom()
+            overall_pb.update(msg=None, transport_msg=msg)

